@@ -23,21 +23,20 @@
 #include "PluginProcessor.h"
 #include "PluginEditor.h"
 
-
 //==============================================================================
-DistanceCompensatorAudioProcessor::DistanceCompensatorAudioProcessor()
-: AudioProcessorBase (
+DistanceCompensatorAudioProcessor::DistanceCompensatorAudioProcessor() :
+    AudioProcessorBase (
 #ifndef JucePlugin_PreferredChannelConfigurations
-                      BusesProperties()
-#if ! JucePlugin_IsMidiEffect
-#if ! JucePlugin_IsSynth
-                  .withInput  ("Input",  juce::AudioChannelSet::discreteChannels (64), true)
+        BusesProperties()
+    #if ! JucePlugin_IsMidiEffect
+        #if ! JucePlugin_IsSynth
+            .withInput ("Input", juce::AudioChannelSet::discreteChannels (64), true)
+        #endif
+            .withOutput ("Output", juce::AudioChannelSet::discreteChannels (64), true)
+    #endif
+            ,
 #endif
-                  .withOutput ("Output", juce::AudioChannelSet::discreteChannels (64), true)
-#endif
-                  ,
-#endif
-createParameterLayout())
+        createParameterLayout())
 {
     // get pointers to the parameters
     inputChannelsSetting = parameters.getRawParameterValue ("inputChannelsSetting");
@@ -50,8 +49,6 @@ createParameterLayout())
     referenceY = parameters.getRawParameterValue ("referenceY");
     referenceZ = parameters.getRawParameterValue ("referenceZ");
 
-
-
     // add listeners to parameter changes
     parameters.addParameterListener ("inputChannelsSetting", this);
     parameters.addParameterListener ("speedOfSound", this);
@@ -60,7 +57,8 @@ createParameterLayout())
 
     for (int i = 0; i < 64; ++i)
     {
-        enableCompensation[i] = parameters.getRawParameterValue ("enableCompensation" + juce::String (i));
+        enableCompensation[i] =
+            parameters.getRawParameterValue ("enableCompensation" + juce::String (i));
         parameters.addParameterListener ("enableCompensation" + juce::String (i), this);
 
         distance[i] = parameters.getRawParameterValue ("distance" + juce::String (i));
@@ -69,37 +67,37 @@ createParameterLayout())
 
     // global properties
     juce::PropertiesFile::Options options;
-    options.applicationName     = "DistanceCompensator";
-    options.filenameSuffix      = "settings";
-    options.folderName          = "IEM";
+    options.applicationName = "DistanceCompensator";
+    options.filenameSuffix = "settings";
+    options.folderName = "IEM";
     options.osxLibrarySubFolder = "Preferences";
 
     properties.reset (new juce::PropertiesFile (options));
     lastDir = juce::File (properties->getValue ("presetFolder"));
 
-    tempValues.resize(64);
+    tempValues.resize (64);
 }
 
 DistanceCompensatorAudioProcessor::~DistanceCompensatorAudioProcessor()
 {
 }
 
-
 float DistanceCompensatorAudioProcessor::distanceToGainInDecibels (const float distance)
 {
-    jassert(distance >= 1.0f);
-    const float gainInDecibels = juce::Decibels::gainToDecibels (1.0f / pow(distance, *distanceExponent));
+    jassert (distance >= 1.0f);
+    const float gainInDecibels =
+        juce::Decibels::gainToDecibels (1.0f / pow (distance, *distanceExponent));
     return gainInDecibels;
 }
 
 float DistanceCompensatorAudioProcessor::distanceToDelayInSeconds (const float distance)
 {
-    jassert(distance >= 1.0f);
+    jassert (distance >= 1.0f);
     const float delayInSeconds = distance / *speedOfSound;
     return delayInSeconds;
 }
 
-void DistanceCompensatorAudioProcessor::setLastDir(juce::File newLastDir)
+void DistanceCompensatorAudioProcessor::setLastDir (juce::File newLastDir)
 {
     lastDir = newLastDir;
     const juce::var v (lastDir.getFullPathName());
@@ -108,19 +106,20 @@ void DistanceCompensatorAudioProcessor::setLastDir(juce::File newLastDir)
 
 void DistanceCompensatorAudioProcessor::loadConfiguration (const juce::File& configFile)
 {
-    juce::ValueTree loudspeakers {"Loudspeakers"};
+    juce::ValueTree loudspeakers { "Loudspeakers" };
 
-    juce::Result result = ConfigurationHelper::parseFileForLoudspeakerLayout (configFile, loudspeakers, nullptr);
-    if (!result.wasOk())
+    juce::Result result =
+        ConfigurationHelper::parseFileForLoudspeakerLayout (configFile, loudspeakers, nullptr);
+    if (! result.wasOk())
     {
-        DBG("Configuration could not be loaded.");
+        DBG ("Configuration could not be loaded.");
         MailBox::Message newMessage;
         newMessage.messageColour = juce::Colours::red;
         newMessage.headline = "Error loading configuration";
         newMessage.text = result.getErrorMessage();
         messageToEditor = newMessage;
         updateMessage = true;
-        DBG(result.getErrorMessage());
+        DBG (result.getErrorMessage());
     }
     else
     {
@@ -130,25 +129,30 @@ void DistanceCompensatorAudioProcessor::loadConfiguration (const juce::File& con
         int maxChannel = 0;
         for (int i = 0; i < nLsp; ++i)
         {
-            auto lsp = loudspeakers.getChild(i);
-            const bool isImaginary = lsp.getProperty("Imaginary");
+            auto lsp = loudspeakers.getChild (i);
+            const bool isImaginary = lsp.getProperty ("Imaginary");
             if (isImaginary)
                 continue;
 
-            const float radius = lsp.getProperty("Radius");
-            const float azimuth = lsp.getProperty("Azimuth");
-            const float elevation = lsp.getProperty("Elevation");
-            const int channel = lsp.getProperty("Channel");
+            const float radius = lsp.getProperty ("Radius");
+            const float azimuth = lsp.getProperty ("Azimuth");
+            const float elevation = lsp.getProperty ("Elevation");
+            const int channel = lsp.getProperty ("Channel");
 
-            const juce::Vector3D<float> cart = Conversions<float>::sphericalToCartesian(juce::degreesToRadians(azimuth), juce::degreesToRadians(elevation), radius);
-            loadedLoudspeakerPositions.add({cart, channel});
+            const juce::Vector3D<float> cart =
+                Conversions<float>::sphericalToCartesian (juce::degreesToRadians (azimuth),
+                                                          juce::degreesToRadians (elevation),
+                                                          radius);
+            loadedLoudspeakerPositions.add ({ cart, channel });
             if (channel > maxChannel)
                 maxChannel = channel;
         }
 
-        DBG("num lsps: " << loadedLoudspeakerPositions.size());
+        DBG ("num lsps: " << loadedLoudspeakerPositions.size());
         if (maxChannel > 0)
-            parameters.getParameter("inputChannelsSetting")->setValueNotifyingHost (parameters.getParameterRange("inputChannelsSetting" ).convertTo0to1(maxChannel));
+            parameters.getParameter ("inputChannelsSetting")
+                ->setValueNotifyingHost (parameters.getParameterRange ("inputChannelsSetting")
+                                             .convertTo0to1 (maxChannel));
         updateParameters();
     }
 }
@@ -156,7 +160,7 @@ void DistanceCompensatorAudioProcessor::loadConfiguration (const juce::File& con
 //==============================================================================
 int DistanceCompensatorAudioProcessor::getNumPrograms()
 {
-    return 1;   // NB: some hosts don't cope very well if you tell them there are 0 programs,
+    return 1; // NB: some hosts don't cope very well if you tell them there are 0 programs,
     // so this should be at least 1, even if you're not really implementing programs.
 }
 
@@ -181,7 +185,7 @@ void DistanceCompensatorAudioProcessor::changeProgramName (int index, const juce
 //==============================================================================
 void DistanceCompensatorAudioProcessor::prepareToPlay (double sampleRate, int samplesPerBlock)
 {
-    checkInputAndOutput(this, *inputChannelsSetting, 0, true);
+    checkInputAndOutput (this, *inputChannelsSetting, 0, true);
 
     juce::dsp::ProcessSpec specs;
     specs.sampleRate = sampleRate;
@@ -201,12 +205,13 @@ void DistanceCompensatorAudioProcessor::releaseResources()
     // spare memory, etc.
 }
 
-void DistanceCompensatorAudioProcessor::processBlock (juce::AudioSampleBuffer& buffer, juce::MidiBuffer& midiMessages)
+void DistanceCompensatorAudioProcessor::processBlock (juce::AudioSampleBuffer& buffer,
+                                                      juce::MidiBuffer& midiMessages)
 {
-    checkInputAndOutput(this, *inputChannelsSetting, 0, false);
+    checkInputAndOutput (this, *inputChannelsSetting, 0, false);
     juce::ScopedNoDenormals noDenormals;
 
-    const int totalNumInputChannels  = getTotalNumInputChannels();
+    const int totalNumInputChannels = getTotalNumInputChannels();
     const int totalNumOutputChannels = getTotalNumOutputChannels();
 
     for (int i = totalNumInputChannels; i < totalNumOutputChannels; ++i)
@@ -235,17 +240,15 @@ juce::AudioProcessorEditor* DistanceCompensatorAudioProcessor::createEditor()
 //==============================================================================
 void DistanceCompensatorAudioProcessor::getStateInformation (juce::MemoryBlock& destData)
 {
-  auto state = parameters.copyState();
+    auto state = parameters.copyState();
 
-  auto oscConfig = state.getOrCreateChildWithName ("OSCConfig", nullptr);
-  oscConfig.copyPropertiesFrom (oscParameterInterface.getConfig(), nullptr);
+    auto oscConfig = state.getOrCreateChildWithName ("OSCConfig", nullptr);
+    oscConfig.copyPropertiesFrom (oscParameterInterface.getConfig(), nullptr);
 
-  std::unique_ptr<juce::XmlElement> xml (state.createXml());
-  copyXmlToBinary (*xml, destData);
+    std::unique_ptr<juce::XmlElement> xml (state.createXml());
+    copyXmlToBinary (*xml, destData);
 }
 
-
-
 void DistanceCompensatorAudioProcessor::setStateInformation (const void* data, int sizeInBytes)
 {
     // You should use this method to restore your parameters from this memory block,
@@ -258,7 +261,8 @@ void DistanceCompensatorAudioProcessor::setStateInformation (const void* data, i
             loadedLoudspeakerPositions.clear();
             if (parameters.state.hasProperty ("OSCPort")) // legacy
             {
-                oscParameterInterface.getOSCReceiver().connect (parameters.state.getProperty ("OSCPort", juce::var (-1)));
+                oscParameterInterface.getOSCReceiver().connect (
+                    parameters.state.getProperty ("OSCPort", juce::var (-1)));
                 parameters.state.removeProperty ("OSCPort", nullptr);
             }
 
@@ -266,13 +270,13 @@ void DistanceCompensatorAudioProcessor::setStateInformation (const void* data, i
             if (oscConfig.isValid())
                 oscParameterInterface.setConfig (oscConfig);
         }
-
 }
 
 //==============================================================================
-void DistanceCompensatorAudioProcessor::parameterChanged (const juce::String &parameterID, float newValue)
+void DistanceCompensatorAudioProcessor::parameterChanged (const juce::String& parameterID,
+                                                          float newValue)
 {
-    DBG("Parameter with ID " << parameterID << " has changed. New value: " << newValue);
+    DBG ("Parameter with ID " << parameterID << " has changed. New value: " << newValue);
 
     if (parameterID == "inputChannelsSetting")
     {
@@ -290,12 +294,12 @@ void DistanceCompensatorAudioProcessor::parameterChanged (const juce::String &pa
     {
         updateGains();
     }
-    else if (parameterID.startsWith("distance"))
+    else if (parameterID.startsWith ("distance"))
     {
         updateDelays();
         updateGains();
     }
-    else if (parameterID.startsWith("enableCompensation"))
+    else if (parameterID.startsWith ("enableCompensation"))
     {
         updateDelays();
         updateGains();
@@ -323,14 +327,15 @@ void DistanceCompensatorAudioProcessor::updateDelays()
     }
 
     const int nActive = tempValues.size();
-    const float maxDelay = juce::FloatVectorOperations::findMaximum (tempValues.getRawDataPointer(), nActive);
+    const float maxDelay =
+        juce::FloatVectorOperations::findMaximum (tempValues.getRawDataPointer(), nActive);
 
     for (int i = 0; i < nCh; ++i)
     {
         if (*enableCompensation[i] >= 0.5f)
-            delay.setDelayTime(i, maxDelay - distanceToDelayInSeconds (*distance[i]));
+            delay.setDelayTime (i, maxDelay - distanceToDelayInSeconds (*distance[i]));
         else
-            delay.setDelayTime(i, 0.0f);
+            delay.setDelayTime (i, 0.0f);
     }
 }
 
@@ -340,7 +345,6 @@ void DistanceCompensatorAudioProcessor::updateGains()
         return;
     tempValues.clearQuick();
 
-
     const int selected = juce::roundToInt (inputChannelsSetting->load());
     int nCh;
     if (selected > 0)
@@ -355,13 +359,14 @@ void DistanceCompensatorAudioProcessor::updateGains()
     }
     const int nActive = tempValues.size();
 
-    const float minGain = juce::FloatVectorOperations::findMinimum (tempValues.getRawDataPointer(), nActive);
+    const float minGain =
+        juce::FloatVectorOperations::findMinimum (tempValues.getRawDataPointer(), nActive);
 
     float ref = 0.0f;
     if (*gainNormalization >= 0.5f) // zero mean
     {
         for (int i = 0; i < nActive; ++i)
-            ref += tempValues.getUnchecked(i);
+            ref += tempValues.getUnchecked (i);
         ref /= nActive;
     }
     else
@@ -369,15 +374,14 @@ void DistanceCompensatorAudioProcessor::updateGains()
         ref = minGain;
     }
 
-
-    DBG("Gain ref: " << ref);
+    DBG ("Gain ref: " << ref);
 
     for (int i = 0; i < nCh; ++i)
     {
         if (*enableCompensation[i] >= 0.5f)
         {
             gain.setGainDecibels (i, ref - distanceToGainInDecibels (*distance[i]));
-            DBG(i << ": " << ref - distanceToGainInDecibels (*distance[i]));
+            DBG (i << ": " << ref - distanceToGainInDecibels (*distance[i]));
         }
         else
             gain.setGainDecibels (i, 0.0f);
@@ -389,11 +393,12 @@ void DistanceCompensatorAudioProcessor::updateParameters()
     const int nLsp = loadedLoudspeakerPositions.size();
     if (nLsp == 0)
     {
-        DBG("No loudspeakers loaded.");
+        DBG ("No loudspeakers loaded.");
         MailBox::Message newMessage;
         newMessage.messageColour = juce::Colours::red;
         newMessage.headline = "Can't update reference position.";
-        newMessage.text = "The reference position can only be updated, if a loudspeaker layout has been loaded. An already loaded layout will vanish every time the session is reloaded.";
+        newMessage.text =
+            "The reference position can only be updated, if a loudspeaker layout has been loaded. An already loaded layout will vanish every time the session is reloaded.";
         messageToEditor = newMessage;
         updateMessage = true;
         return;
@@ -403,22 +408,26 @@ void DistanceCompensatorAudioProcessor::updateParameters()
 
     for (int i = 0; i < 64; ++i)
     {
-        parameters.getParameter ("enableCompensation" + juce::String (i))->setValueNotifyingHost (0.0f);
+        parameters.getParameter ("enableCompensation" + juce::String (i))
+            ->setValueNotifyingHost (0.0f);
         parameters.getParameter ("distance" + juce::String (i))->setValueNotifyingHost (0.0f);
     }
 
-    const juce::Vector3D<float> reference {*referenceX, *referenceY, *referenceZ};
+    const juce::Vector3D<float> reference { *referenceX, *referenceY, *referenceZ };
 
     for (int i = 0; i < nLsp; ++i)
     {
-        auto lsp = loadedLoudspeakerPositions.getReference(i);
-        const float radius = juce::jmax(1.0f, (lsp.position - reference).length());
+        auto lsp = loadedLoudspeakerPositions.getReference (i);
+        const float radius = juce::jmax (1.0f, (lsp.position - reference).length());
 
-        parameters.getParameter ("enableCompensation" + juce::String (lsp.channel - 1))->setValueNotifyingHost (1.0f);
-        parameters.getParameter ("distance" + juce::String (lsp.channel - 1))->setValueNotifyingHost (parameters.getParameterRange ("distance" + juce::String (lsp.channel - 1)).convertTo0to1 (radius));
+        parameters.getParameter ("enableCompensation" + juce::String (lsp.channel - 1))
+            ->setValueNotifyingHost (1.0f);
+        parameters.getParameter ("distance" + juce::String (lsp.channel - 1))
+            ->setValueNotifyingHost (
+                parameters.getParameterRange ("distance" + juce::String (lsp.channel - 1))
+                    .convertTo0to1 (radius));
     }
 
-
     updatingParameters = false;
 
     updateDelays();
@@ -427,34 +436,35 @@ void DistanceCompensatorAudioProcessor::updateParameters()
 
 void DistanceCompensatorAudioProcessor::updateBuffers()
 {
-    DBG("IOHelper:  input size: " << input.getSize());
-    DBG("IOHelper: output size: " << output.getSize());
+    DBG ("IOHelper:  input size: " << input.getSize());
+    DBG ("IOHelper: output size: " << output.getSize());
 
     updateDelays();
     updateGains();
 }
 
-
 //==============================================================================
-const bool DistanceCompensatorAudioProcessor::processNotYetConsumedOSCMessage (const juce::OSCMessage &message)
+const bool DistanceCompensatorAudioProcessor::processNotYetConsumedOSCMessage (
+    const juce::OSCMessage& message)
 {
     juce::String prefix ("/" + juce::String (JucePlugin_Name));
     if (! message.getAddressPattern().toString().startsWith (prefix))
         return false;
 
     juce::OSCMessage msg (message);
-    msg.setAddressPattern (message.getAddressPattern().toString().substring (juce::String (JucePlugin_Name).length() + 1));
+    msg.setAddressPattern (message.getAddressPattern().toString().substring (
+        juce::String (JucePlugin_Name).length() + 1));
 
-    if (msg.getAddressPattern().toString ().equalsIgnoreCase ("/loadFile") && msg.size() >= 1)
+    if (msg.getAddressPattern().toString().equalsIgnoreCase ("/loadFile") && msg.size() >= 1)
     {
-        if (msg[0].isString ())
+        if (msg[0].isString())
         {
-            juce::File fileToLoad (msg[0].getString ());
+            juce::File fileToLoad (msg[0].getString());
             loadConfiguration (fileToLoad);
         }
         return true;
     }
-    else if (msg.getAddressPattern().toString ().equalsIgnoreCase ("/updateReference"))
+    else if (msg.getAddressPattern().toString().equalsIgnoreCase ("/updateReference"))
     {
         updateParameters();
         return true;
@@ -463,78 +473,142 @@ const bool DistanceCompensatorAudioProcessor::processNotYetConsumedOSCMessage (c
     return false;
 }
 
-
-
 //==============================================================================
-std::vector<std::unique_ptr<juce::RangedAudioParameter>> DistanceCompensatorAudioProcessor::createParameterLayout()
+std::vector<std::unique_ptr<juce::RangedAudioParameter>>
+    DistanceCompensatorAudioProcessor::createParameterLayout()
 {
     // add your audio parameters here
     std::vector<std::unique_ptr<juce::RangedAudioParameter>> params;
 
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "inputChannelsSetting",
+        "Number of input channels ",
+        "",
+        juce::NormalisableRange<float> (0.0f, 64.0f, 1.0f),
+        0.0f,
+        [] (float value) { return value < 0.5f ? "Auto" : juce::String (value); },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("inputChannelsSetting", "Number of input channels ", "",
-                                     juce::NormalisableRange<float> (0.0f, 64.0f, 1.0f), 0.0f,
-                                     [](float value) {return value < 0.5f ? "Auto" : juce::String (value);}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "enableGains",
+        "Enable Gain Compensation",
+        "",
+        juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f),
+        1.0f,
+        [] (float value)
+        {
+            if (value >= 0.5f)
+                return "Yes";
+            else
+                return "No";
+        },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("enableGains", "Enable Gain Compensation", "",
-                                     juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
-                                     [](float value) {
-                                         if (value >= 0.5f) return "Yes";
-                                         else return "No";
-                                     }, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "enableDelays",
+        "Enable Delay Compensation",
+        "",
+        juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f),
+        1.0f,
+        [] (float value)
+        {
+            if (value >= 0.5f)
+                return "Yes";
+            else
+                return "No";
+        },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("enableDelays", "Enable Delay Compensation", "",
-                                     juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
-                                     [](float value) {
-                                         if (value >= 0.5f) return "Yes";
-                                         else return "No";
-                                     }, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "speedOfSound",
+        "Speed of Sound",
+        "m/s",
+        juce::NormalisableRange<float> (330.0, 350.0, 0.1f),
+        343.2f,
+        [] (float value) { return juce::String (value, 1); },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("speedOfSound", "Speed of Sound", "m/s",
-                                     juce::NormalisableRange<float> (330.0, 350.0, 0.1f), 343.2f,
-                                     [](float value) {return juce::String (value, 1);}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "distanceExponent",
+        "Distance-Gain Exponent",
+        "",
+        juce::NormalisableRange<float> (0.5f, 1.5f, 0.1f),
+        1.0f,
+        [] (float value) { return juce::String (value, 1); },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("distanceExponent", "Distance-Gain Exponent", "",
-                                     juce::NormalisableRange<float> (0.5f, 1.5f, 0.1f), 1.0f,
-                                     [](float value) {return juce::String (value, 1);}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "gainNormalization",
+        "Gain Normalization",
+        "",
+        juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f),
+        0.0f,
+        [] (float value)
+        {
+            if (value >= 0.5f)
+                return "Zero-mean";
+            else
+                return "Attenuation only";
+        },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("gainNormalization", "Gain Normalization", "",
-                                     juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 0.0f,
-                                     [](float value) {
-                                         if (value >= 0.5f) return "Zero-mean";
-                                         else return "Attenuation only";
-                                     }, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "referenceX",
+        "Reference position x",
+        "m",
+        juce::NormalisableRange<float> (-20.0f, 20.0f, 0.01f),
+        0.0f,
+        [] (float value) { return juce::String (value, 2); },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("referenceX", "Reference position x", "m",
-                                     juce::NormalisableRange<float> (-20.0f, 20.0f, 0.01f), 0.0f,
-                                     [](float value) {return juce::String (value, 2);}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "referenceY",
+        "Reference position x",
+        "m",
+        juce::NormalisableRange<float> (-20.0f, 20.0f, 0.01f),
+        0.0f,
+        [] (float value) { return juce::String (value, 2); },
+        nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("referenceY", "Reference position x", "m",
-                                     juce::NormalisableRange<float> (-20.0f, 20.0f, 0.01f), 0.0f,
-                                     [](float value) {return juce::String (value, 2);}, nullptr));
-
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("referenceZ", "Reference position x", "m",
-                                     juce::NormalisableRange<float> (-20.0f, 20.0f, 0.01f), 0.0f,
-                                     [](float value) {return juce::String (value, 2);}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay (
+        "referenceZ",
+        "Reference position x",
+        "m",
+        juce::NormalisableRange<float> (-20.0f, 20.0f, 0.01f),
+        0.0f,
+        [] (float value) { return juce::String (value, 2); },
+        nullptr));
 
     for (int i = 0; i < 64; ++i)
     {
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("enableCompensation" + juce::String (i), "Enable Compensation of loudspeaker " + juce::String (i + 1), "",
-                                        juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
-                                        [](float value) {
-                                            if (value >= 0.5f) return "ON";
-                                            else return "OFF";
-                                        }, nullptr));
+        params.push_back (OSCParameterInterface::createParameterTheOldWay (
+            "enableCompensation" + juce::String (i),
+            "Enable Compensation of loudspeaker " + juce::String (i + 1),
+            "",
+            juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f),
+            1.0f,
+            [] (float value)
+            {
+                if (value >= 0.5f)
+                    return "ON";
+                else
+                    return "OFF";
+            },
+            nullptr));
 
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("distance" + juce::String (i), "Distance of loudspeaker " + juce::String (i + 1), "m",
-                                        juce::NormalisableRange<float> (1.0f, 50.0f, 0.01f), 5.0f,
-                                        [](float value) {return juce::String (value, 2);}, nullptr));
+        params.push_back (OSCParameterInterface::createParameterTheOldWay (
+            "distance" + juce::String (i),
+            "Distance of loudspeaker " + juce::String (i + 1),
+            "m",
+            juce::NormalisableRange<float> (1.0f, 50.0f, 0.01f),
+            5.0f,
+            [] (float value) { return juce::String (value, 2); },
+            nullptr));
     }
 
     return params;
 }
 
-
 //==============================================================================
 // This creates new instances of the plugin..
 juce::AudioProcessor* JUCE_CALLTYPE createPluginFilter()
