@@ -22,14 +22,19 @@
 
 #include "PluginEditor.h"
 
-
 //==============================================================================
-MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor (MultiBandCompressorAudioProcessor& p, juce::AudioProcessorValueTreeState& vts)
-    : juce::AudioProcessorEditor (&p), processor (p), valueTreeState (vts), footer (p.getOSCParameterInterface()), filterBankVisualizer (20.0f, 20000.0f, -15.0f, 20.0f, 5.0f, p.getSampleRate(), numFreqBands)
+MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor (
+    MultiBandCompressorAudioProcessor& p,
+    juce::AudioProcessorValueTreeState& vts) :
+    juce::AudioProcessorEditor (&p),
+    processor (p),
+    valueTreeState (vts),
+    footer (p.getOSCParameterInterface()),
+    filterBankVisualizer (20.0f, 20000.0f, -15.0f, 20.0f, 5.0f, p.getSampleRate(), numFilterBands)
 {
     // ============== BEGIN: essentials ======================
     // set GUI size and lookAndFeel
-    setResizeLimits (980, 980*0.6, 1600, 1600*0.6); // use this to create a resizable GUI
+    setResizeLimits (980, 980 * 0.6, 1600, 1600 * 0.6); // use this to create a resizable GUI
     setLookAndFeel (&globalLaF);
 
     // make title and footer visible, and set the PluginName
@@ -39,74 +44,87 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
     addAndMakeVisible (&footer);
     // ============= END: essentials ========================
 
-    cbNormalizationAtachement = std::make_unique<ComboBoxAttachment> (valueTreeState, "useSN3D", *title.getInputWidgetPtr()->getNormCbPointer());
-    cbOrderAtachement = std::make_unique<ComboBoxAttachment> (valueTreeState,"orderSetting", *title.getInputWidgetPtr()->getOrderCbPointer());
+    cbNormalizationAtachement =
+        std::make_unique<ComboBoxAttachment> (valueTreeState,
+                                              "useSN3D",
+                                              *title.getInputWidgetPtr()->getNormCbPointer());
+    cbOrderAtachement =
+        std::make_unique<ComboBoxAttachment> (valueTreeState,
+                                              "orderSetting",
+                                              *title.getInputWidgetPtr()->getOrderCbPointer());
 
     tooltips.setMillisecondsBeforeTipAppears (800);
     tooltips.setOpaque (false);
 
+    const juce::Colour colours[numFilterBands] = { juce::Colours::cornflowerblue,
+                                                   juce::Colours::greenyellow,
+                                                   juce::Colours::yellow,
+                                                   juce::Colours::orangered };
 
-    const juce::Colour colours[numFreqBands] =
+    for (int i = 0; i < numFilterBands; ++i)
     {
-        juce::Colours::cornflowerblue,
-        juce::Colours::greenyellow,
-        juce::Colours::yellow,
-        juce::Colours::orangered
-    };
-
-
-    for (int i = 0; i < numFreqBands; ++i)
-    {
-
         // ==== COMPRESSOR VISUALIZATION ====
         compressorVisualizers.add (new CompressorVisualizer (p.getCompressor (i)));
         addAndMakeVisible (compressorVisualizers[i]);
 
-
         // ===== GR METERS =====
         addAndMakeVisible (&GRmeter[i]);
         GRmeter[i].setMinLevel (-25.0f);
         GRmeter[i].setColour (juce::Colours::red.withMultipliedAlpha (0.8f));
         GRmeter[i].setGainReductionMeter (true);
 
-
         // ==== SLIDERS ====
         addAndMakeVisible (&slThreshold[i]);
-        slThresholdAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "threshold" + juce::String (i), slThreshold[i]);
+        slThresholdAttachment[i] =
+            std::make_unique<SliderAttachment> (valueTreeState,
+                                                "threshold" + juce::String (i),
+                                                slThreshold[i]);
         slThreshold[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slThreshold[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
         slThreshold[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slThreshold[i].setTextValueSuffix (" dB");
 
         addAndMakeVisible (&slKnee[i]);
-        slKneeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "knee" + juce::String (i), slKnee[i]);
+        slKneeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState,
+                                                                  "knee" + juce::String (i),
+                                                                  slKnee[i]);
         slKnee[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slKnee[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
         slKnee[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slKnee[i].setTextValueSuffix (" dB");
 
         addAndMakeVisible (&slRatio[i]);
-        slRatioAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "ratio" + juce::String (i), slRatio[i]);
+        slRatioAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState,
+                                                                   "ratio" + juce::String (i),
+                                                                   slRatio[i]);
         slRatio[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slRatio[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
         slRatio[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
 
         addAndMakeVisible (&slAttackTime[i]);
-        slAttackTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "attack" + juce::String (i), slAttackTime[i]);
+        slAttackTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState,
+                                                                        "attack" + juce::String (i),
+                                                                        slAttackTime[i]);
         slAttackTime[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slAttackTime[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
         slAttackTime[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slRatio[i].setTextValueSuffix (" ms");
 
         addAndMakeVisible (&slReleaseTime[i]);
-        slReleaseTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "release" + juce::String (i), slReleaseTime[i]);
+        slReleaseTimeAttachment[i] =
+            std::make_unique<SliderAttachment> (valueTreeState,
+                                                "release" + juce::String (i),
+                                                slReleaseTime[i]);
         slReleaseTime[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slReleaseTime[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
         slReleaseTime[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slReleaseTime[i].setTextValueSuffix (" ms");
 
         addAndMakeVisible (&slMakeUpGain[i]);
-        slMakeUpGainAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "makeUpGain" + juce::String (i), slMakeUpGain[i]);
+        slMakeUpGainAttachment[i] =
+            std::make_unique<SliderAttachment> (valueTreeState,
+                                                "makeUpGain" + juce::String (i),
+                                                slMakeUpGain[i]);
         slMakeUpGain[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slMakeUpGain[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
         slMakeUpGain[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
@@ -114,7 +132,6 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
         slMakeUpGain[i].setName (juce::String ("MakeUpGain" + juce::String (i)));
         slMakeUpGain[i].addListener (this);
 
-
         // ===== LABELS =====
         addAndMakeVisible (&lbKnee[i]);
         lbKnee[i].setText ("Knee");
@@ -140,50 +157,57 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
         lbRelease[i].setText ("Release");
         lbRelease[i].setTextColour (globalLaF.ClFace);
 
-
         // ==== BUTTONS ====
-        tbSolo[i].setColour (juce::ToggleButton::tickColourId, juce::Colour (0xFFFFFF66).withMultipliedAlpha (0.85f));
+        tbSolo[i].setColour (juce::ToggleButton::tickColourId,
+                             juce::Colour (0xFFFFFF66).withMultipliedAlpha (0.85f));
         tbSolo[i].setScaleFontSize (0.75f);
         tbSolo[i].setButtonText ("S");
         tbSolo[i].setName ("solo" + juce::String (i));
         tbSolo[i].setTooltip ("Solo band #" + juce::String (i));
-        soloAttachment[i]  = std::make_unique<juce::AudioProcessorValueTreeState::ButtonAttachment> (valueTreeState, "solo" + juce::String (i), tbSolo[i]);
+        soloAttachment[i] = std::make_unique<juce::AudioProcessorValueTreeState::ButtonAttachment> (
+            valueTreeState,
+            "solo" + juce::String (i),
+            tbSolo[i]);
         tbSolo[i].setClickingTogglesState (true);
         tbSolo[i].addListener (this);
         addAndMakeVisible (&tbSolo[i]);
 
-        tbBypass[i].setColour (juce::ToggleButton::tickColourId, juce::Colour (0xFF5bAE87).withMultipliedAlpha (0.85f));
+        tbBypass[i].setColour (juce::ToggleButton::tickColourId,
+                               juce::Colour (0xFF5bAE87).withMultipliedAlpha (0.85f));
         tbBypass[i].setScaleFontSize (0.75f);
         tbBypass[i].setButtonText ("B");
         tbBypass[i].setName ("bypass" + juce::String (i));
         tbBypass[i].setTooltip ("Bypass band #" + juce::String (i));
-        bypassAttachment[i] = std::make_unique<juce::AudioProcessorValueTreeState::ButtonAttachment> (valueTreeState, "bypass" + juce::String (i), tbBypass[i]);
+        bypassAttachment[i] =
+            std::make_unique<juce::AudioProcessorValueTreeState::ButtonAttachment> (
+                valueTreeState,
+                "bypass" + juce::String (i),
+                tbBypass[i]);
         tbBypass[i].setClickingTogglesState (true);
         tbBypass[i].addListener (this);
         addAndMakeVisible (&tbBypass[i]);
     }
 
-
     // ==== FILTER VISUALIZATION ====
     juce::dsp::IIR::Coefficients<double>::Ptr coeffs1;
     juce::dsp::IIR::Coefficients<double>::Ptr coeffs2;
-    for (int i = 0; i < numFreqBands; ++i)
+    for (int i = 0; i < numFilterBands; ++i)
     {
         switch (i)
         {
-            case (int)MultiBandCompressorAudioProcessor::FrequencyBands::Low:
+            case (int) MultiBandCompressorAudioProcessor::FrequencyBands::Low:
                 coeffs1 = processor.lowPassLRCoeffs[1];
                 coeffs2 = processor.lowPassLRCoeffs[0];
                 break;
-            case (int)MultiBandCompressorAudioProcessor::FrequencyBands::MidLow:
+            case (int) MultiBandCompressorAudioProcessor::FrequencyBands::MidLow:
                 coeffs1 = processor.lowPassLRCoeffs[1];
                 coeffs2 = processor.highPassLRCoeffs[0];
                 break;
-            case (int)MultiBandCompressorAudioProcessor::FrequencyBands::MidHigh:
+            case (int) MultiBandCompressorAudioProcessor::FrequencyBands::MidHigh:
                 coeffs1 = processor.highPassLRCoeffs[1];
                 coeffs2 = processor.lowPassLRCoeffs[2];
                 break;
-            case (int)MultiBandCompressorAudioProcessor::FrequencyBands::High:
+            case (int) MultiBandCompressorAudioProcessor::FrequencyBands::High:
                 coeffs1 = processor.highPassLRCoeffs[1];
                 coeffs2 = processor.highPassLRCoeffs[2];
                 break;
@@ -197,7 +221,6 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
     addAndMakeVisible (&filterBankVisualizer);
 
-
     // SHOW OVERALL MAGNITUDE BUTTON
     tbOverallMagnitude.setColour (juce::ToggleButton::tickColourId, juce::Colours::white);
     tbOverallMagnitude.setButtonText ("show total magnitude");
@@ -206,16 +229,19 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
     tbOverallMagnitude.addListener (this);
     addAndMakeVisible (&tbOverallMagnitude);
 
-
     // ==== CROSSOVER SLIDERS ====
-    for (int i = 0; i < numFreqBands-1; ++i)
+    for (int i = 0; i < numFilterBands - 1; ++i)
     {
-        slCrossoverAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "crossover" + juce::String (i), slCrossover[i]);
+        slCrossoverAttachment[i] =
+            std::make_unique<SliderAttachment> (valueTreeState,
+                                                "crossover" + juce::String (i),
+                                                slCrossover[i]);
         addAndMakeVisible (&slCrossover[i]);
         slCrossover[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
         slCrossover[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
-        slCrossover[i].setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClRotSliderArrow);
-        slCrossover[i].setTooltip ("Crossover Frequency " + juce::String (i+1));
+        slCrossover[i].setColour (juce::Slider::rotarySliderOutlineColourId,
+                                  globalLaF.ClRotSliderArrow);
+        slCrossover[i].setTooltip ("Crossover Frequency " + juce::String (i + 1));
         slCrossover[i].setName ("Crossover" + juce::String (i));
         slCrossover[i].addListener (this);
 
@@ -223,7 +249,6 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
         filterBankVisualizer.addCrossover (&slCrossover[i]);
     }
 
-
     // ==== METERS - INPUT/OUTPUT ====
     addAndMakeVisible (&omniInputMeter);
     omniInputMeter.setMinLevel (-60.0f);
@@ -241,49 +266,48 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
     lbOutput.setText ("Output");
     lbOutput.setTextColour (globalLaF.ClFace);
 
-
     // ==== MASTER CONTROLS ====
     addAndMakeVisible (&slMasterThreshold);
     slMasterThreshold.setName ("MasterThreshold");
-    addAndMakeVisible (&lbThreshold[numFreqBands]);
-    lbThreshold[numFreqBands].setText ("Thresh.");
-    lbThreshold[numFreqBands].setTextColour (globalLaF.ClFace);
+    addAndMakeVisible (&lbThreshold[numFilterBands]);
+    lbThreshold[numFilterBands].setText ("Thresh.");
+    lbThreshold[numFilterBands].setTextColour (globalLaF.ClFace);
 
     addAndMakeVisible (&slMasterKnee);
     slMasterKnee.setName ("MasterKnee");
-    addAndMakeVisible (&lbKnee[numFreqBands]);
-    lbKnee[numFreqBands].setText ("Knee");
-    lbKnee[numFreqBands].setTextColour (globalLaF.ClFace);
+    addAndMakeVisible (&lbKnee[numFilterBands]);
+    lbKnee[numFilterBands].setText ("Knee");
+    lbKnee[numFilterBands].setTextColour (globalLaF.ClFace);
 
     addAndMakeVisible (&slMasterMakeUpGain);
     slMasterMakeUpGain.setName ("MasterMakeUpGain");
-    addAndMakeVisible (&lbMakeUpGain[numFreqBands]);
-    lbMakeUpGain[numFreqBands].setText ("Gain");
-    lbMakeUpGain[numFreqBands].setTextColour (globalLaF.ClFace);
+    addAndMakeVisible (&lbMakeUpGain[numFilterBands]);
+    lbMakeUpGain[numFilterBands].setText ("Gain");
+    lbMakeUpGain[numFilterBands].setTextColour (globalLaF.ClFace);
 
     addAndMakeVisible (&slMasterRatio);
     slMasterRatio.setName ("MasterMakeUpGain");
-    addAndMakeVisible (&lbRatio[numFreqBands]);
-    lbRatio[numFreqBands].setText ("Ratio");
-    lbRatio[numFreqBands].setTextColour (globalLaF.ClFace);
+    addAndMakeVisible (&lbRatio[numFilterBands]);
+    lbRatio[numFilterBands].setText ("Ratio");
+    lbRatio[numFilterBands].setTextColour (globalLaF.ClFace);
 
     addAndMakeVisible (&slMasterAttackTime);
     slMasterAttackTime.setName ("MasterAttackTime");
-    addAndMakeVisible (&lbAttack[numFreqBands]);
-    lbAttack[numFreqBands].setText ("Attack");
-    lbAttack[numFreqBands].setTextColour (globalLaF.ClFace);
+    addAndMakeVisible (&lbAttack[numFilterBands]);
+    lbAttack[numFilterBands].setText ("Attack");
+    lbAttack[numFilterBands].setTextColour (globalLaF.ClFace);
 
     addAndMakeVisible (&slMasterReleaseTime);
     slMasterReleaseTime.setName ("MasterReleaseTime");
-    addAndMakeVisible (&lbRelease[numFreqBands]);
-    lbRelease[numFreqBands].setText ("Rel.");
-    lbRelease[numFreqBands].setTextColour (globalLaF.ClFace);
+    addAndMakeVisible (&lbRelease[numFilterBands]);
+    lbRelease[numFilterBands].setText ("Rel.");
+    lbRelease[numFilterBands].setTextColour (globalLaF.ClFace);
 
     gcMasterControls.setText ("Master controls");
     addAndMakeVisible (&gcMasterControls);
 
     // add sliders to master controls
-    for (int i = 0; i < numFreqBands; ++i)
+    for (int i = 0; i < numFilterBands; ++i)
     {
         slMasterThreshold.addSlave (slThreshold[i]);
         slMasterKnee.addSlave (slKnee[i]);
@@ -293,10 +317,9 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
         slMasterReleaseTime.addSlave (slReleaseTime[i]);
     }
 
-
     /* resized () is called here, because otherwise the compressorVisualizers won't be drawn to the GUI until one manually resizes the window.
     It seems resized() somehow gets called *before* the constructor and therefore juce::OwnedArray<CompressorVisualizers> is still empty on the first resized call... */
-    resized ();
+    resized();
 
     // start timer after everything is set up properly
     startTimer (50);
@@ -311,7 +334,6 @@ MultiBandCompressorAudioProcessorEditor::~MultiBandCompressorAudioProcessorEdito
 void MultiBandCompressorAudioProcessorEditor::paint (juce::Graphics& g)
 {
     g.fillAll (globalLaF.ClBackground);
-
 }
 
 void MultiBandCompressorAudioProcessorEditor::resized()
@@ -333,9 +355,8 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     area.removeFromBottom (5);
     // =========== END: header and footer =================
 
-
     // ==== SPLIT INTO 4 BASIC SECTIONS ====
-//    const float leftToRightRatio = 0.87;
+    //    const float leftToRightRatio = 0.87;
     const int leftToRightGap = 6;
     const float filterBankToLowerRatio = 0.34f;
     const float crossoverAndButtonToCompressorsRatio = 0.1645f;
@@ -343,19 +364,20 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const int compressorToCrossoverAndButtonGap = 2;
 
     // split
-//    juce::Rectangle<int> leftArea = area.removeFromLeft (area.proportionOfWidth (leftToRightRatio));
-//    juce::Rectangle<int> rightArea (area);
+    //    juce::Rectangle<int> leftArea = area.removeFromLeft (area.proportionOfWidth (leftToRightRatio));
+    //    juce::Rectangle<int> rightArea (area);
 
     juce::Rectangle<int> rightArea = area.removeFromRight (130);
     area.removeFromRight (leftToRightGap);
     juce::Rectangle<int> leftArea (area);
 
-
-//    leftArea.removeFromRight (leftToRightGap / 2);
-//    rightArea.removeFromLeft (leftToRightGap / 2);
-    juce::Rectangle<int> filterBankArea = leftArea.removeFromTop (leftArea.proportionOfHeight (filterBankToLowerRatio));
+    //    leftArea.removeFromRight (leftToRightGap / 2);
+    //    rightArea.removeFromLeft (leftToRightGap / 2);
+    juce::Rectangle<int> filterBankArea =
+        leftArea.removeFromTop (leftArea.proportionOfHeight (filterBankToLowerRatio));
     juce::Rectangle<int> compressorArea = leftArea;
-    juce::Rectangle<int> crossoverAndButtonArea = compressorArea.removeFromTop (compressorArea.proportionOfHeight (crossoverAndButtonToCompressorsRatio));
+    juce::Rectangle<int> crossoverAndButtonArea = compressorArea.removeFromTop (
+        compressorArea.proportionOfHeight (crossoverAndButtonToCompressorsRatio));
 
     // safeguard against haphephobia
     filterBankArea.removeFromBottom (filterToCrossoverAndButtonGap / 2);
@@ -363,11 +385,9 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     crossoverAndButtonArea.removeFromBottom (compressorToCrossoverAndButtonGap / 2);
     compressorArea.removeFromTop (compressorToCrossoverAndButtonGap / 2);
 
-
     // ==== FILTER VISUALIZATION ====
     filterBankVisualizer.setBounds (filterBankArea);
 
-
     // ==== BUTTONS AND CROSSOVER SLIDERS ====
     const int crossoverToButtonGap = 32;
     const int buttonToButtonGap = 0;
@@ -378,11 +398,11 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     juce::Rectangle<int> bypassButtonArea;
     juce::Rectangle<int> crossoverArea;
 
-    const int buttonsWidth = crossoverAndButtonArea.getWidth () / (numFreqBands + (numFreqBands-1)*crossoverToButtonsRatio);
+    const int buttonsWidth = crossoverAndButtonArea.getWidth()
+                             / (numFilterBands + (numFilterBands - 1) * crossoverToButtonsRatio);
     const int crossoverSliderWidth = buttonsWidth * crossoverToButtonsRatio;
 
-
-    for (int i = 0; i < numFreqBands; ++i)
+    for (int i = 0; i < numFilterBands; ++i)
     {
         // juce::Buttons
         bypassButtonArea = crossoverAndButtonArea.removeFromLeft (buttonsWidth);
@@ -390,11 +410,15 @@ void MultiBandCompressorAudioProcessorEditor::resized()
         soloButtonArea = bypassButtonArea.removeFromLeft (bypassButtonArea.proportionOfWidth (0.5));
         soloButtonArea.removeFromRight (buttonToButtonGap / 2);
         bypassButtonArea.removeFromLeft (buttonToButtonGap / 2);
-        tbSolo[i].setBounds (soloButtonArea.reduced (soloButtonArea.proportionOfWidth (trimButtonsWidth), soloButtonArea.proportionOfHeight (trimButtonsHeight)));
-        tbBypass[i].setBounds  (bypassButtonArea.reduced (bypassButtonArea.proportionOfWidth (trimButtonsWidth), bypassButtonArea.proportionOfHeight (trimButtonsHeight)));
+        tbSolo[i].setBounds (
+            soloButtonArea.reduced (soloButtonArea.proportionOfWidth (trimButtonsWidth),
+                                    soloButtonArea.proportionOfHeight (trimButtonsHeight)));
+        tbBypass[i].setBounds (
+            bypassButtonArea.reduced (bypassButtonArea.proportionOfWidth (trimButtonsWidth),
+                                      bypassButtonArea.proportionOfHeight (trimButtonsHeight)));
 
         // juce::Sliders
-        if (i < numFreqBands - 1)
+        if (i < numFilterBands - 1)
         {
             crossoverArea = crossoverAndButtonArea.removeFromLeft (crossoverSliderWidth);
             slCrossover[i].setBounds (crossoverArea.reduced (crossoverToButtonGap / 2, 0));
@@ -411,16 +435,21 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const int meterToCharacteristicGap = 6;
     const float trimMeterHeightRatio = 0.02f;
 
-    compressorArea.reduce (((compressorArea.getWidth() - (numFreqBands-1) * bandToBandGap) % numFreqBands) / 2, 0);
-    const int widthPerBand = ((compressorArea.getWidth() - (numFreqBands-1) * bandToBandGap) / numFreqBands);
-    juce::Rectangle<int> characteristicArea, paramArea, paramRow1, paramRow2, labelRow1, labelRow2, grMeterArea;
+    compressorArea.reduce (
+        ((compressorArea.getWidth() - (numFilterBands - 1) * bandToBandGap) % numFilterBands) / 2,
+        0);
+    const int widthPerBand =
+        ((compressorArea.getWidth() - (numFilterBands - 1) * bandToBandGap) / numFilterBands);
+    juce::Rectangle<int> characteristicArea, paramArea, paramRow1, paramRow2, labelRow1, labelRow2,
+        grMeterArea;
 
-    for (int i = 0; i < numFreqBands; ++i)
+    for (int i = 0; i < numFilterBands; ++i)
     {
         characteristicArea = compressorArea.removeFromLeft (widthPerBand);
 
         // Compressor parameters
-        paramArea = characteristicArea.removeFromBottom (characteristicArea.proportionOfHeight (paramToCharacteristiscRatio));
+        paramArea = characteristicArea.removeFromBottom (
+            characteristicArea.proportionOfHeight (paramToCharacteristiscRatio));
         paramArea.removeFromTop (paramToCharacteristicGap / 2);
         characteristicArea.removeFromBottom (paramToCharacteristicGap / 2);
 
@@ -449,55 +478,62 @@ void MultiBandCompressorAudioProcessorEditor::resized()
         slReleaseTime[i].setBounds (paramRow2.removeFromLeft (sliderWidth));
 
         // Gain-Reduction meter
-        grMeterArea = characteristicArea.removeFromRight (characteristicArea.proportionOfWidth (meterToCharacteristicRatio));
+        grMeterArea = characteristicArea.removeFromRight (
+            characteristicArea.proportionOfWidth (meterToCharacteristicRatio));
         grMeterArea.removeFromLeft (meterToCharacteristicGap / 2);
         characteristicArea.removeFromRight (meterToCharacteristicGap / 2);
-        GRmeter[i].setBounds (grMeterArea.reduced (0, grMeterArea.proportionOfHeight (trimMeterHeightRatio)));
+        GRmeter[i].setBounds (
+            grMeterArea.reduced (0, grMeterArea.proportionOfHeight (trimMeterHeightRatio)));
 
         // Compressor characteristic
-        if (!(compressorVisualizers.isEmpty()))
+        if (! (compressorVisualizers.isEmpty()))
             compressorVisualizers[i]->setBounds (characteristicArea);
 
-        if (i < numFreqBands-1)
+        if (i < numFilterBands - 1)
             compressorArea.removeFromLeft (bandToBandGap);
     }
 
-
     // ==== INPUT & OUTPUT METER ====
     const float labelToMeterRatio = 0.1f;
     const int meterToMeterGap = 10;
 
-    juce::Rectangle<int> meterArea = rightArea.removeFromTop (rightArea.proportionOfHeight (filterBankToLowerRatio));
+    juce::Rectangle<int> meterArea =
+        rightArea.removeFromTop (rightArea.proportionOfHeight (filterBankToLowerRatio));
     meterArea.reduce (meterArea.proportionOfWidth (0.18f), 0);
-    juce::Rectangle<int> inputMeterArea = meterArea.removeFromLeft (meterArea.proportionOfWidth (0.5f));
+    juce::Rectangle<int> inputMeterArea =
+        meterArea.removeFromLeft (meterArea.proportionOfWidth (0.5f));
     juce::Rectangle<int> outputMeterArea = meterArea;
     inputMeterArea.removeFromRight (meterToMeterGap / 2);
     outputMeterArea.removeFromLeft (meterToMeterGap / 2);
-    juce::Rectangle<int> inputMeterLabelArea = inputMeterArea.removeFromBottom (inputMeterArea.proportionOfHeight (labelToMeterRatio));
-    juce::Rectangle<int> outputMeterLabelArea = outputMeterArea.removeFromBottom (outputMeterArea.proportionOfHeight (labelToMeterRatio));
+    juce::Rectangle<int> inputMeterLabelArea =
+        inputMeterArea.removeFromBottom (inputMeterArea.proportionOfHeight (labelToMeterRatio));
+    juce::Rectangle<int> outputMeterLabelArea =
+        outputMeterArea.removeFromBottom (outputMeterArea.proportionOfHeight (labelToMeterRatio));
 
     omniInputMeter.setBounds (inputMeterArea);
     omniOutputMeter.setBounds (outputMeterArea);
     lbInput.setBounds (inputMeterLabelArea);
     lbOutput.setBounds (outputMeterLabelArea);
 
-
     // ==== MASTER SLIDERS + LABELS ====
-    const float masterToUpperArea =  0.5;
+    const float masterToUpperArea = 0.5;
     const float labelToSliderRatio = 0.24f;
     const int trimFromGroupComponentHeader = 25;
     const float trimSliderHeight = 0.125f;
     const float trimSliderWidth = 0.00f;
     const int masterToCompressorSectionGap = 18;
 
-    juce::Rectangle<int> masterArea = rightArea.removeFromBottom (rightArea.proportionOfHeight (masterToUpperArea));
+    juce::Rectangle<int> masterArea =
+        rightArea.removeFromBottom (rightArea.proportionOfHeight (masterToUpperArea));
     masterArea.removeFromLeft (masterToCompressorSectionGap);
     gcMasterControls.setBounds (masterArea);
     masterArea.removeFromTop (trimFromGroupComponentHeader);
 
-    juce::Rectangle<int> sliderRow = masterArea.removeFromTop (masterArea.proportionOfHeight (0.5f));
-//    sliderRow.reduce (sliderRow.proportionOfWidth (trimSliderWidth), sliderRow.proportionOfHeight (trimSliderHeight));
-    juce::Rectangle<int> labelRow = sliderRow.removeFromBottom (sliderRow.proportionOfHeight (labelToSliderRatio));
+    juce::Rectangle<int> sliderRow =
+        masterArea.removeFromTop (masterArea.proportionOfHeight (0.5f));
+    //    sliderRow.reduce (sliderRow.proportionOfWidth (trimSliderWidth), sliderRow.proportionOfHeight (trimSliderHeight));
+    juce::Rectangle<int> labelRow =
+        sliderRow.removeFromBottom (sliderRow.proportionOfHeight (labelToSliderRatio));
 
     const int masterSliderWidth = 35;
     DBG (sliderRow.getWidth());
@@ -505,21 +541,21 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     slMasterThreshold.setBounds (sliderRow.removeFromLeft (masterSliderWidth));
     slMasterKnee.setBounds (sliderRow.removeFromLeft (masterSliderWidth));
     slMasterMakeUpGain.setBounds (sliderRow.removeFromLeft (masterSliderWidth));
-    lbThreshold[numFreqBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
-    lbKnee[numFreqBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
-    lbMakeUpGain[numFreqBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
+    lbThreshold[numFilterBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
+    lbKnee[numFilterBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
+    lbMakeUpGain[numFilterBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
 
     sliderRow = masterArea;
-    sliderRow.reduce (sliderRow.proportionOfWidth (trimSliderWidth), sliderRow.proportionOfHeight (trimSliderHeight));
+    sliderRow.reduce (sliderRow.proportionOfWidth (trimSliderWidth),
+                      sliderRow.proportionOfHeight (trimSliderHeight));
     labelRow = sliderRow.removeFromBottom (sliderRow.proportionOfHeight (labelToSliderRatio));
 
     slMasterRatio.setBounds (sliderRow.removeFromLeft (masterSliderWidth));
     slMasterAttackTime.setBounds (sliderRow.removeFromLeft (masterSliderWidth));
     slMasterReleaseTime.setBounds (sliderRow.removeFromLeft (masterSliderWidth));
-    lbRatio[numFreqBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
-    lbAttack[numFreqBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
-    lbRelease[numFreqBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
-
+    lbRatio[numFilterBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
+    lbAttack[numFilterBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
+    lbRelease[numFilterBands].setBounds (labelRow.removeFromLeft (masterSliderWidth));
 
     // ==== FILTERBANKVISUALIZER SETTINGS ====
     const float trimHeight = 0.4f;
@@ -527,24 +563,24 @@ void MultiBandCompressorAudioProcessorEditor::resized()
 
     rightArea.removeFromLeft (trimFromLeft);
     rightArea.reduce (0, rightArea.proportionOfHeight (trimHeight));
-    juce::Rectangle<int> totalMagnitudeButtonArea = rightArea.removeFromTop (rightArea.proportionOfHeight (0.5));
+    juce::Rectangle<int> totalMagnitudeButtonArea =
+        rightArea.removeFromTop (rightArea.proportionOfHeight (0.5));
     tbOverallMagnitude.setBounds (totalMagnitudeButtonArea);
-
 }
 
-
-void MultiBandCompressorAudioProcessorEditor::sliderValueChanged (juce::Slider *slider)
+void MultiBandCompressorAudioProcessorEditor::sliderValueChanged (juce::Slider* slider)
 {
     if (slider->getName().startsWith ("MakeUpGain"))
     {
-        filterBankVisualizer.updateMakeUpGain (slider->getName().getLastCharacters (1).getIntValue(), slider->getValue());
+        filterBankVisualizer.updateMakeUpGain (
+            slider->getName().getLastCharacters (1).getIntValue(),
+            slider->getValue());
         return;
     }
 }
 
 void MultiBandCompressorAudioProcessorEditor::buttonClicked (juce::Button* button)
 {
-
     if (button->getName().startsWith ("bypass"))
     {
         int i = button->getName().getLastCharacters (1).getIntValue();
@@ -559,14 +595,12 @@ void MultiBandCompressorAudioProcessorEditor::buttonClicked (juce::Button* butto
     {
         displayOverallMagnitude = button->getToggleState();
         if (displayOverallMagnitude)
-            filterBankVisualizer.activateOverallMagnitude ();
+            filterBankVisualizer.activateOverallMagnitude();
         else
-            filterBankVisualizer.deactivateOverallMagnitude ();
+            filterBankVisualizer.deactivateOverallMagnitude();
     }
-
 }
 
-
 void MultiBandCompressorAudioProcessorEditor::timerCallback()
 {
     // === update titleBar widgets according to available input/output channel counts
@@ -576,14 +610,13 @@ void MultiBandCompressorAudioProcessorEditor::timerCallback()
     if (processor.repaintFilterVisualization.get())
     {
         processor.repaintFilterVisualization = false;
-        filterBankVisualizer.updateFreqBandResponses ();
+        filterBankVisualizer.updateFreqBandResponses();
     }
 
     omniInputMeter.setLevel (processor.inputPeak.get());
     omniOutputMeter.setLevel (processor.outputPeak.get());
 
-
-    for (int i = 0; i < numFreqBands; ++i)
+    for (int i = 0; i < numFilterBands; ++i)
     {
         const auto gainReduction = processor.maxGR[i].get();
 
